import Vue from 'vue'
import Vuex from 'vuex'

import io from 'socket.io-client'

import { API_HOST } from '@/config.js'

Vue.use(Vuex)

export default new Vuex.Store({
  state: {
    feeds: {},
    images: {},
    scenes: {}
  },
  getters: {
    scenes: state => state.scenes
  },
  mutations: {
    LOAD_SCENES (state, data) {
      console.info('Scenes:', data)
      state.scenes = data
    },
    LOAD_IMAGES (state, data) {
      console.info('Images:', data)
      state.images = data
    },
    LOAD_FEEDS (state, data) {
      console.info('Feeds:', data)
      state.feeds = data
    }
  },
  actions: {
    initialize ({ commit }) {
      this.socket = io(`//${API_HOST}`)

      this.socket.on('connect', () => {
        console.log('Socket.IO connected:', this.socket.id)
      })

      this.socket.on('feeds', (data) => commit('LOAD_FEEDS', data))
      this.socket.on('scenes', (data) => commit('LOAD_SCENES', data))
      this.socket.on('images', (data) => commit('LOAD_IMAGES', data))
    },
    setSceneAlpha ({ commit }, [scene, type, alpha]) {
      console.info(scene.id, type, alpha)

      if (!type) {
        type = ''
      } else {
        type += '_'
      }

      scene[type + 'alpha'] = alpha
      this.socket.emit('scene_mod', {
        'id': scene.id,
        [type + 'alpha']: alpha
      })
    },
    setFrameAlpha ({ commit }, [sceneId, frameId, side, alpha]) {
      console.info('Setting alpha for', frameId, alpha)
      this.state.scenes[sceneId].frames[frameId][side].alpha = alpha
      this.socket.emit('frame_mod', {
        'scene_id': sceneId, 'frame_id': frameId, [side]: {'alpha': alpha}
      })
    },
    setFrameSource ({ commit }, [sceneId, frameId, side, source]) {
      this.state.scenes[sceneId].frames[frameId][side]['source'] = source
      this.socket.emit('frame_mod', {
        'scene_id': sceneId, 'frame_id': frameId, [side]: {'source': source}
      })
    },
    setFrameActive ({ commit }, [sceneId, frameId, active]) {
      this.state.scenes[sceneId].frames[frameId]['active'] = active
      this.socket.emit('frame_mod', {
        'scene_id': sceneId, 'frame_id': frameId, 'active': active
      })
    },
    sceneFade ({ commit }, scene) {
      this.socket.emit('scene_fade', { id: scene.id })
    },
    sceneCut ({ commit }, scene) {
      this.socket.emit('scene_cut', { id: scene.id })
    }
  }
})
